@@ -355,6 +355,8 @@ int main(int argc, char *argv[])
 		{
 			fprintf(stderr, "'%s' is a strange URL\n", getcopy);
 			fprintf(stderr, "Expected: %s...\n", http_string);
+			if (strncasecmp(getcopy, "https://", 8) == 0)
+				fprintf(stderr, "Did you forget to add the '-l' switch to the httping commandline?\n");
 			return 2;
 		}
 
@@ -423,7 +425,22 @@ int main(int argc, char *argv[])
 #endif
 
 	request = mymalloc(strlen(get) + 4096, "request");
-	sprintf(request, "%s %s HTTP/1.0\r\n", get_instead_of_head?"GET":"HEAD", get);
+	if (proxyhost)
+		sprintf(request, "%s %s HTTP/1.0\r\n", get_instead_of_head?"GET":"HEAD", get);
+	else
+	{
+		char *dummy = get, *slash;
+		if (strncasecmp(dummy, "http://", 7) == 0)
+			dummy += 7;
+		else if (strncasecmp(dummy, "https://", 7) == 0)
+			dummy += 8;
+
+		slash = strchr(dummy, '/');
+		if (slash)
+			sprintf(request, "%s %s HTTP/1.0\r\n", get_instead_of_head?"GET":"HEAD", slash);
+		else
+			sprintf(request, "%s / HTTP/1.0\r\n", get_instead_of_head?"GET":"HEAD");
+	}
 	if (useragent)
 		sprintf(&request[strlen(request)], "User-Agent: %s\r\n", useragent);
 	else
@@ -462,7 +479,7 @@ int main(int argc, char *argv[])
 	while((curncount < count || count == -1) && stop == 0)
 	{
 		double ms;
-		double dstart, dend, dafter_connect;
+		double dstart, dend, dafter_connect = 0.0;
 		char *reply;
 		int Bps = 0;
 		char is_compressed = 0;
